@@ -20,7 +20,7 @@
 
 ***************************************************************************/
 
-//     zfuncs.h   version  v.3.9
+//     zfuncs.h   version  v.4.6
 
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -100,7 +100,6 @@ int checkinstall(cchar *prog, ...);                                        //  c
 char * fgets_trim(char * buff, int maxcc, FILE *, int bf = 0);             //  fgets + trim trailing \n \r (blanks)
 int samedirk(cchar *file1, cchar *file2);                                  //  returns 1 if files in same directory
 int parsefile(cchar *path, char **dir, char **file, char **ext);           //  parse a filespec
-int zmondirk(cchar *action, cchar *dirk, char **file);                     //  monitor a directory for changes   v.2.16
 
 //  measure CPU time spent in a function or code block within a function
 extern volatile double   cpu_profile_timer;                                //  internal data tables
@@ -231,22 +230,25 @@ double spline2(double x);                                                  //  r
 
 //  application initialization and administration
 
-#define ZTXmaxent 1000                                                     //  max. translation strings
-#define ZTXmaxcc 2000                                                      //  max. cc per string
+#define ZTXmaxent 2000                                                     //  max. translation strings
+#define ZTXmaxcc 4000                                                      //  max. cc per string
 
-int initz_appfiles(cchar *appname, ...);                                   //  find app dirs, copy initial files
+int zinitapp(cchar *appname, ...);                                         //  initz. app directories and files   v.4.1
+cchar * get_zinstalloc();                                                  //  get /usr or /usr/local  ...        v.4.1
 cchar * get_zuserdir();                                                    //  get /home/user/.appname/
 cchar * get_zdatadir();                                                    //  get install directory
-cchar * get_zdocdir();                                                     //  get document directory          v.3.8
+cchar * get_zdocdir();                                                     //  get document directory             v.3.8
 
 void showz_userguide(cchar *context = 0);                                  //  show user guide in new process
 void showz_readme();                                                       //  show README file in popup window
 void showz_changelog();                                                    //  show changelog file in popup window
 void showz_translations();                                                 //  show TRANSLATIONS file in popup window
-void zmake_launcher(cchar *categories, cchar *genericname);                //  create desktop icon/launcher    v.2.18
+void showz_doctext(cchar *file);                                           //  show text file (or .gz) in a popup window
+void zmake_menu_launcher(cchar *command, cchar *cats, cchar *generic);     //  add desktop menu and launcher      v.4.1
 
-int ZTXinit(cchar *lang);                                                  //  setup for message translation
+void ZTXinit(cchar *lang);                                                 //  setup for message translation
 cchar *ZTX(cchar *english);                                                //  get translation for English message
+void ZTX_translation_start();                                              //  start online translation
 
 /**************************************************************************
    GTK utility functions
@@ -310,6 +312,7 @@ struct zwidget  {
       int         homog;                           //  hbox/vbox: equal spacing flag
       int         expand;                          //  expandable flag
       int         space;                           //  extra padding space (pixels)
+      int         wrap;                            //  wrap mode for edit widget
       GtkWidget   *widget;                         //  GTK widget pointer
 };
 
@@ -318,6 +321,9 @@ struct zdialog  {
       void        *eventCB;                        //  widget event user callback function
       int         zstat;                           //  dialog status (from completion button)
       int         disabled;                        //  widget signals/events are disabled
+      int         saveposn;                        //  save and recall window position each use
+      cchar       *help_topic;                     //  optional help topic
+      GtkWidget   *parent;                         //  parent window or null
       GtkWidget   *compbutt[zdmaxbutts];           //  dialog completion buttons
       zwidget     widget[zdmaxwidgets];            //  dialog widgets (EOF = type = 0)
 };
@@ -327,20 +333,22 @@ zdialog *zdialog_new(cchar *title, GtkWidget *parent, ...);                //  c
 int zdialog_add_widget(zdialog *zd,                                        //  add widget to zdialog
       cchar *type, cchar *name, cchar *pname,                              //  required args
       cchar *data = 0, int scc = 0, int homog = 0,                         //  optional args
-      int expand = 0, int space = 0);
+      int expand = 0, int space = 0, int wrap = 0);
 
 int zdialog_add_widget(zdialog *zd,                                        //  add widget to zdialog
       cchar *type, cchar *name, cchar *pname,                              //  (alternative form)
-      cchar *data, cchar *options);                                        //  "scc=nn|homog|expand|space=nn"
+      cchar *data, cchar *options);                                        //  "scc=nn|homog|expand|space=nn|wrap"
 
 GtkWidget * zdialog_widget(zdialog *zd, cchar *name);                      //  GTK widget from zdialog widget name
 int zdialog_set_group(zdialog *zd, cchar *radio1, ...);                    //  set group ID for set of radio buttons
 int zdialog_resize(zdialog *zd, int width, int height);                    //  set size > widget sizes
 int zdialog_put_data(zdialog *zd, cchar *name, cchar *data);               //  put data in widget (entry, spin ...)
 cchar * zdialog_get_data(zdialog *zd, cchar *name);                        //  get widget data
+int zdialog_set_limits(zdialog *zd, cchar *name, double min, double max);  //  set new widget limits (spin, scale)
+void zdialog_help(zdialog *zd, cchar *help_topic);                         //  set help topic for zdialog
 
 typedef int zdialog_event(zdialog *zd, cchar *name);                       //  widget event callback function
-int zdialog_run(zdialog *zd, zdialog_event = 0);                           //  run dialog, handle events
+int zdialog_run(zdialog *zd, zdialog_event = 0, cchar *posn = 0);          //  run dialog, handle events
 
 int zdialog_send_event(zdialog *zd, cchar *event);                         //  send an event to an active dialog   v.2.17
 int zdialog_send_response(zdialog *zd, int zstat);                         //  complete a dialog, set status   v.2.23
@@ -366,6 +374,10 @@ int zdialog_cb_delete(zdialog *zd, cchar *name, cchar *data);              //  d
 int zdialog_cb_clear(zdialog *zd, cchar *name);                            //  clear all combo box entries         v.2.4
 int zdialog_cb_popup(zdialog *zd, cchar *name);                            //  show all combo box list entries     v.3.8
 
+int  zdialog_positions(cchar *action);                                     //  load or save zdialog window positions
+void zdialog_set_position(zdialog *zd, cchar *posn);                       //  set initial/new zdialog window position
+void zdialog_save_position(zdialog *zd);                                   //  save zdialog window position
+
 /**************************************************************************/
 
 //   GTK misc. utility functioins
@@ -377,8 +389,8 @@ int popup_command(cchar *command, int ww = 400, int hh = 300, GtkWidget *parent
 void zmessageACK(GtkWidget *parent, cchar *pMess, ... );                   //  display message, wait for OK
 void zmessLogACK(GtkWidget *parent, cchar *pMess, ... );                   //  same, with log to STDOUT
 int zmessageYN(GtkWidget *parent, cchar *pMess, ... );                     //  display message, wait for YES or NO
-void zmessage_help(GtkWidget *parent, cchar *topic, cchar *mess, ...);     //  message box, help button > user guide topic
-zdialog * zmessage_post(GtkWidget *parent, cchar *pMess, ...);             //  display message until killed    v.3.7
+void zmessage_help(GtkWidget *parent, cchar *topic, cchar *mess, ...);     //  message box, [help] > user guide topic
+zdialog * zmessage_post(GtkWidget *parent, int secs, cchar *mess, ...);    //  display message until timeout or cancel
 char * zdialog_text(GtkWidget *parent, cchar * title, cchar * initext);    //  get short text input from user
 
 //  file chooser dialogs for 1 file or multiple files
@@ -397,16 +409,18 @@ GdkCursor * zmakecursor(cchar *iconfile);                                  //  m
 //   GDK/GTK image file utility functions
 //   for functions returning char *, caller responsible for zfree()
 
-char * image_gallery(cchar *filez, cchar *action, int Nth = 1,             //  display image gallery window, navigate,
-                     void func(char *file) = 0, GtkWidget *parent = 0);    //    do callback for clicked thumbnails
-char ** image_gallery_getfiles(char *startdir, GtkWidget *parent = 0);     //  get selected files from gallery window
-
 void print_imagefile(cchar *file, cchar *format = 0, cchar *orien = 0);    //  print image file (.jpg .png .tif)  v.3.4
 GdkPixbuf * gdk_pixbuf_rotate(GdkPixbuf *, double deg, int alfa = 0);      //  rotate pixbuf through any angle
-int image_position(cchar *file, int *count = 0);                           //  get curr. image position, total image count
+
+char * image_gallery(cchar *filez, cchar *action, int Nth = 0,             //  display image gallery window, navigate, 
+                      void ufunc(int Nth) = 0, GtkWidget *parent = 0);     //    do callback for clicked thumbnails
+
+int image_gallery_position(cchar *file, int Nth);                          //  get relative position of file in gallery
 int image_file_type(cchar *file);                                          //  determine if directory or image file type
-char * image_thumbfile(cchar *imagefile);                                  //  get thumbnail filespec, create if missing
-GdkPixbuf * image_thumbnail(cchar *imagefile, int size = 0);               //  get thumbnail pixbuf, create if missing
+char * image_thumbfile(char *imagefile);                                   //  get thumbnail filespec, create if missing
+GdkPixbuf * image_thumbnail(char *imagefile, int size = 0);                //  get thumbnail pixbuf, create if missing
+
+char ** image_gallery_getfiles(char *startdir, GtkWidget *parent = 0);     //  select files from gallery window
 
 /**************************************************************************/
 
